@@ -194,63 +194,114 @@ class DialogAbout(wx.Dialog):
 
 class DialogSettings(wx.Dialog):
 	def __init__(self, parent):
-		#-1 , "Settings", size = wx.DefaultSize, , 
-		#	 style = wx.DEFAULT_DIALOG_STYLE):
 		wx.Dialog.__init__(self, parent, -1, _("Settings"), pos = wx.DefaultPosition)#, size =(450,-1))
 		
-		## The layout begins:
-		font = wx.Font(16, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
-		self.labelHeading = wx.StaticText(self, -1, _("Settings"))
-		self.labelHeading.SetFont(font)
+		verticalSizer = wx.BoxSizer(wx.VERTICAL)
+	
+		nb = wx.Notebook(self, -1, style=0)
+		PANE1= wx.Panel(nb, -1)
+		PANE2 = wx.Panel(nb, -1)
 
-		self.label_1 = wx.StaticText(self, -1, _("Sample text:"))
-		self.inputSampleString = wx.TextCtrl(self, -1, fpsys.config.text, size = (200, -1)) 
+		## The layout of PANE1 begins:
+		font = wx.Font(16, fpsys.DFAM, wx.NORMAL, wx.FONTWEIGHT_BOLD)
+		labelHeading = wx.StaticText(self, -1, _("Settings"))
+		labelHeading.SetFont(font)
+
+		label_1 = wx.StaticText(PANE1, -1, _("Sample text:"))
+		self.inputSampleString = wx.TextCtrl(PANE1, -1, fpsys.config.text, size = (200, -1)) 
 		self.inputSampleString.SetFocus()
 		
-		self.label_2 = wx.StaticText(self, -1, _("Point size:"))
-		self.inputPointSize = wx.SpinCtrl(self, -1, "")
+		label_2 = wx.StaticText(PANE1, -1, _("Point size:"))
+		self.inputPointSize = wx.SpinCtrl(PANE1, -1, "")
 		self.inputPointSize.SetRange(1, 500)
 		self.inputPointSize.SetValue(fpsys.config.points)
 		
-		self.label_3 = wx.StaticText(self, -1, _("Page length:"))
-		self.inputPageLen = wx.SpinCtrl(self, -1, "")
+		label_3 = wx.StaticText(PANE1, -1, _("Page length:"))
+		self.inputPageLen = wx.SpinCtrl(PANE1, -1, "")
 		self.inputPageLen.SetRange(1, 5000) # It's your funeral!
 		self.inputPageLen.SetValue(fpsys.config.numinpage) 
+		self.inputPageLen.SetToolTip( wx.ToolTip( _("Beware large numbers!") ) )
 
-		box = wx.BoxSizer(wx.HORIZONTAL)
-		verticalSizer = wx.BoxSizer(wx.VERTICAL)
-		box.Add(verticalSizer, 1, flag = wx.ALL, border = 10)
+		PANE1sizer = wx.FlexGridSizer( rows=3, cols=2, hgap=5, vgap=8 )
+		PANE1sizer.Add(label_1, 0, wx.ALIGN_RIGHT | wx.ALIGN_CENTER_VERTICAL )
+		PANE1sizer.Add(self.inputSampleString, 1, wx.EXPAND )
+		PANE1sizer.Add(label_2, 0, wx.ALIGN_RIGHT | wx.ALIGN_CENTER_VERTICAL )
+		PANE1sizer.Add(self.inputPointSize, 0 )
+		PANE1sizer.Add(label_3, 0, wx.ALIGN_RIGHT | wx.ALIGN_CENTER_VERTICAL )
+		PANE1sizer.Add(self.inputPageLen, 0 )
+
+		PANE1_buffer = wx.BoxSizer( wx.HORIZONTAL )
+		PANE1_buffer.Add( PANE1sizer, 1, wx.EXPAND | wx.ALL, border=10 )
+		PANE1.SetSizer( PANE1_buffer )
+
+
+		## Layout of PANE2
+		## Sept 2009 - Checkbox to ignore/use the font top left adjustment code
+		self.chkAdjust = wx.CheckBox(PANE2, -1, _("Disable font top-left correction."))
+		self.chkAdjust.SetValue(fpsys.config.ignore_adjustments) 
+		self.chkAdjust.SetToolTip( wx.ToolTip( _("Disabling this speeds font drawing up a fraction, but degrades top-left positioning.") ) )
+		PANE2sizer = wx.BoxSizer( wx.VERTICAL )
+		PANE2sizer.Add(self.chkAdjust, 0, wx.ALIGN_LEFT | wx.BOTTOM, border=10 )
+
+		# The Character map choice
+		self.got_apps=fpsys.config.GOT_APPS
+		if self.got_apps:
+			self.CHOSEN_CHARACTER_MAP = fpsys.config.app_char_map
+			print self.CHOSEN_CHARACTER_MAP
+			rb = wx.RadioBox(
+					PANE2, -1, _("Available character map viewers"), wx.DefaultPosition, wx.DefaultSize,
+					self.got_apps, 1, wx.RA_SPECIFY_COLS
+					)
+			if self.CHOSEN_CHARACTER_MAP is None:
+				self.CHOSEN_CHARACTER_MAP = "gucharmap"
+			rb.SetSelection( self.got_apps.index( self.CHOSEN_CHARACTER_MAP ))
+			self.Bind(wx.EVT_RADIOBOX, self.EvtRadioBox, rb)
+			rb.SetToolTip(wx.ToolTip( _("Choose which app to use as a character map viewer.") ))
+			PANE2sizer.Add( rb, 0, wx.ALIGN_LEFT )
+		else:
+			self.CHOSEN_CHARACTER_MAP = None
+			no_app = wx.StaticText(PANE2, -1, _("Could not find a character viewer.\n(Install gucharmap or kfontview.)"))
+			PANE2sizer.Add( no_app, 0, wx.ALIGN_LEFT )
+
+		PANE2_buffer = wx.BoxSizer( wx.HORIZONTAL )
+		PANE2_buffer.Add( PANE2sizer, 1, wx.EXPAND | wx.ALL, border=10 )
+		PANE2.SetSizer( PANE2_buffer )
 		
-		gridSizer = wx.FlexGridSizer( rows=3, cols=2, hgap=5, vgap=8 )
-		
-		verticalSizer.Add(self.labelHeading, 0, wx.ALIGN_LEFT )
+		## Add the panels to the notebook
+		nb.AddPage( PANE1, _("Quick settings") )
+		nb.AddPage( PANE2, _("Voodoo") )
+
+		## Add label and a space to the vertical sizer
+		verticalSizer.Add( labelHeading, 0, wx.ALIGN_LEFT )
 		verticalSizer.Add( (0,5), 0 )
-		
-		gridSizer.Add(self.label_1, 0, wx.ALIGN_RIGHT | wx.ALIGN_CENTER_VERTICAL )
-		gridSizer.Add(self.inputSampleString, 1, wx.EXPAND )
-		gridSizer.Add(self.label_2, 0, wx.ALIGN_RIGHT | wx.ALIGN_CENTER_VERTICAL )
-		gridSizer.Add(self.inputPointSize, 0 )
-		gridSizer.Add(self.label_3, 0, wx.ALIGN_RIGHT | wx.ALIGN_CENTER_VERTICAL )
-		gridSizer.Add(self.inputPageLen, 0 )
-		
-		verticalSizer.Add(gridSizer, 1, wx.EXPAND )
+
+		## Add the notebook
+		verticalSizer.Add( nb, 1, wx.EXPAND | wx.ALL )
 		verticalSizer.Add((0,10),0) #space between bottom of grid and buttons
+
+		## Make a std button group
 		btnsizer = wx.StdDialogButtonSizer()
-		
 		btn = wx.Button(self, wx.ID_OK)
 		btn.SetDefault()
 		btnsizer.AddButton(btn)
-
 		btn = wx.Button(self, wx.ID_CANCEL)
 		btnsizer.AddButton(btn)
 		btnsizer.Realize()
-		
-		verticalSizer.Add(btnsizer, 0, wx.ALIGN_BOTTOM | wx.ALIGN_CENTER_HORIZONTAL, border = 5)
-		
-		self.SetSizer(box)
-		box.Fit(self) # This triggers the sizers to do their thing.
+	
+		## Add button group to vertical sizer
+		verticalSizer.Add( btnsizer, 0, wx.ALIGN_BOTTOM | wx.ALIGN_CENTER_HORIZONTAL, border = 5)
+	
+		## Make a 'buffer' to keep the insides away from the edges of the frame
+		buffer=wx.BoxSizer( wx.HORIZONTAL )
+		## To get border to work use wx.EXPAND | wx.ALL
+		buffer.Add( verticalSizer, 1,wx.EXPAND | wx.ALL,  border=10 )
+
+		self.SetSizer( buffer )
+		buffer.Fit(self)
 		self.Layout()
 
+	def EvtRadioBox(self, event):
+		self.CHOSEN_CHARACTER_MAP = self.got_apps[event.GetInt()]
 
 class SegfaultDialog(wx.Dialog):
 	"""
@@ -260,7 +311,6 @@ class SegfaultDialog(wx.Dialog):
 	"""
 	def __init__(self, parent, culprit):
 		wx.Dialog.__init__(self, parent, -1, _("Oh boy..."), pos = wx.DefaultPosition )
-		
 		## The layout begins:
 		font = wx.Font(16, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
 		self.labelHeading = wx.StaticText(self, -1, _("Fonty Python, um ... crashed."))
@@ -277,9 +327,7 @@ class SegfaultDialog(wx.Dialog):
 		self.culprit = wx.StaticText( self, -1, culprit ) 
 		self.culprit.SetFont( font )
 		
-		box = wx.BoxSizer(wx.HORIZONTAL)
 		verticalSizer = wx.BoxSizer(wx.VERTICAL)
-		box.Add(verticalSizer, 1, flag = wx.ALL, border = 10)
 		verticalSizer.Add(self.labelHeading, 0, 0, 0)
 		verticalSizer.Add(self.ohDear, 0, 0, 0)
 		verticalSizer.Add(self.sadStory, 1, wx.EXPAND, 0)
@@ -292,9 +340,13 @@ class SegfaultDialog(wx.Dialog):
 		btnsizer.Realize()
 				
 		verticalSizer.Add(btnsizer, 0, wx.ALIGN_CENTER_VERTICAL| wx.ALIGN_RIGHT, border = 15)
-		
-		self.SetSizer(box)
-		box.Fit(self)
+		buffer=wx.BoxSizer( wx.HORIZONTAL )
+		buffer.Add( verticalSizer, 1, wx.ALL, border=10 )
+
+		self.SetSizer( buffer )
+		buffer.Fit(self) 
+		self.SetSizer( buffer )
+
 		self.Layout()
 		
 class LocateDirectory(wx.Dialog):
@@ -341,7 +393,7 @@ class DialogCheckFonts( wx.Dialog ):
 		## LEFT
 		leftsz = wx.BoxSizer(wx.VERTICAL)
 
-		font = wx.Font(12, wx.DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
+		font = wx.Font(12, fpsys.DFAM, wx.NORMAL, wx.FONTWEIGHT_BOLD)
 		title = wx.StaticText( self,-1,  _("Choose a directory and double click it to start"))
 		title.SetFont( font )
 		leftsz.Add(title,0,wx.EXPAND | wx.ALL, border=4 )
