@@ -69,7 +69,7 @@ class FontItem( object ):
 		## What kind of bad to the bone am I?
 		## One of FILE_NOT_FOUND, PIL_IO_ERROR, PIL_UNICODE_ERROR, PIL_CANNOT_RENDER
 		self.badstyle = "" 
-		
+
 		## We need the family name and style to be fetched
 		## because we have that filter thingy in the gui
 		## and it uses those strings to search for terms.
@@ -78,6 +78,11 @@ class FontItem( object ):
 		## and we must open the file and query it to know that.
 		self.__queryFontFamilyStyleFlagBad()
 		
+		## Vars used in the rendering stage.
+		self.fx = [None for i in xrange(self.numFaces)] # Position calculated for best top-left of each face image.
+		self.fy = self.fx[:] #Damn! Make a COPY of that list!
+		self.top_left_adjust_completed = False
+
 	def __queryFontFamilyStyleFlagBad( self ):
 		"""
 		Get the family, style and size of entire font.
@@ -158,8 +163,9 @@ class FontItem( object ):
 				## So, before we do a getname and cause a segfault, let's
 				## see whether that font is in segfonts, and if so, skip it.
 				if self.glyphpaf not in fpsys.segfonts:
-					## No point Try-ing here, this segfaults when style/family is Null.
-					fpsys.logSegfaulters( self.glyphpaf ) # record the potential destroyer of apps!
+					# This writes to lastFontBeforeSegfault file. Just in case it crashes the 
+					# app on the .family call below.
+					fpsys.logSegfaulters( self.glyphpaf ) 
 					##
 					## Sep 2009
 					## It has been reported by a user that some fonts have family names (and other info?) that
@@ -172,6 +178,8 @@ class FontItem( object ):
 					## I await help from PIL list.
 
 					#self.family.append( font.getname()[0] ) # old code
+
+					## No point Try-ing here, this segfaults when style/family is Null.
 					self.family.append( fpsys.LSP.ensure_unicode( font.getname()[0] ) )
 
 					self.style.append( font.getname()[1] )
@@ -183,11 +191,10 @@ class FontItem( object ):
 					self.badfontmsg = _("Font causes a segfault. It cannot be drawn.")
 					self.badstyle = "PIL_SEGFAULT_ERROR"
 					break
-				
+
 		self.numFaces = i
 				
-	#def generatePilFont( self, width, maxHeight, enc="unicode" ):
-	def generatePilFont( self, maxHeight, enc="unicode" ):
+	def generatePilFont( self, enc="unicode" ):
 		"""
 		This function seems too similar to the __queryFontFamilyStyleFlagBad one
 		and in many ways it is. I am forced to work with PIL and it's not ideal
@@ -215,7 +222,9 @@ class FontItem( object ):
 					w = 1
 				pilheight = int(h)
 				pilwidth = int(w)
-				pilheight = min( pilheight, maxHeight )
+
+				pilheight += 10
+
 				## Sept 2009 : Fiddled this to produce alpha (ish) images.
 				pilimage = Image.new("RGBA", (pilwidth, pilheight), (0,0,0,0))#(255,255,255,255)) 
 				
@@ -232,7 +241,7 @@ class FontItem( object ):
 				## All is well, so we step ahead to the next *potential* sub-face
 				## and return the font image data.
 				i += 1
-				yield pilimage, pilheight, pilwidth
+				yield pilimage#, pilheight, pilwidth
 
 			except MemoryError:
 				"""
@@ -759,7 +768,7 @@ class Pog(BasicFontList):
 			print _("%s is already installed." % self.name)
 			return
 
-		## We start thinking all is rosy:
+		## We start thinking all is rosey:
 		self.__installed = "yes"
 		## Now we make sure ...
 		if len(self) == 0: 
