@@ -29,8 +29,12 @@ import pathcontrol
 import strings
 import fontcontrol
 
+import wx
 
+import subprocess
 
+## Oct 2009 Default Font Family (System font)
+DFAM=None # Set in wxgui.py in class App()
 
 ## Ensure we have a .fontypython folder and a .fonts folder.
 iPC = pathcontrol.PathControl() #Make an instance - hence the small 'i' (Boy this convention *sure* lasted....)
@@ -151,7 +155,6 @@ def checkFonts( dirtocheck, printer ):
 	
 	Can be called from the cli or the gui.
 	"""
-	import subprocess
 	global segfonts
 	
 	code = """
@@ -292,6 +295,10 @@ class Configure:
 		self.rightSash = 128
 		## Added June 2009
 		self.recurseFolders = False 
+		## Added Sept 2009
+		self.ignore_adjustments = False
+		## Added 3 Oct 2009
+		self.app_char_map = None # A string of an app name.
 
 		self.__setData()
 		
@@ -322,6 +329,8 @@ class Configure:
 			self.leftSash = self.__data['leftSash']
 			self.rightSash = self.__data['rightSash']
 			self.recurseFolders = self.__data['recurseFolders']
+			self.ignore_adjustments = self.__data['ignore_adjustments']
+			self.app_char_map = self.__data['app_char_map']
 			
 		except KeyError:
 			## The conf file has keys that don't work for this version, chances are it's old.
@@ -332,6 +341,29 @@ class Configure:
 				print _("The fontypython config file is damaged.\nPlease remove it and start again")
 				raise SystemExit
 			self.Save()
+		
+		## Oct 2009 -- The Character Map Viewer external app.
+		## See also: dialogues.py
+		self.GOT_APPS = self.make_apps_list()
+		if self.GOT_APPS is []: self.app_char_map = None
+
+	def make_apps_list( self ):
+		'''Return a list of a choice of installed charmap viewers, or []'''
+		def does_app_exist( program ):
+			for path in os.environ.get('PATH', '').split(':'):
+				if os.path.exists(os.path.join(path, program)) and \
+				   not os.path.isdir(os.path.join(path, program)):
+					#return os.path.join(path, program)
+					return program
+			return None
+		validapps = ['gucharmap','kfontview']
+		apps=[]
+		apps.append( does_app_exist(validapps[0]) )
+		apps.append( does_app_exist(validapps[1]) )
+		got_apps=[str(t) for t in apps if t is not None]
+		if self.app_char_map not in validapps: self.app_char_map = None
+		return got_apps
+
 	def dontSaveNumInPage(self, flag):
 		self.__dontSaveNumInPage = flag
 	def __setData(self):
@@ -346,7 +378,9 @@ class Configure:
 								"lastdir" : self.lastdir,
 								"leftSash" : self.leftSash,
 								"rightSash" : self.rightSash,
-								"recurseFolders": self.recurseFolders
+								"recurseFolders": self.recurseFolders,
+								"ignore_adjustments": self.ignore_adjustments,
+								"app_char_map" : self.app_char_map
 								}
 	def Save(self) :
 		#If we are NOT to save the numinpage, then fetch it from what was there before.
@@ -367,7 +401,6 @@ class Configure:
 ## all the modules that use it.
 config = Configure()
 
-
 def instantiateViewFolder( foldername, recurse=False ):
 	"""
 	Creates a Folder object and fills it with FontItem objects
@@ -524,4 +557,3 @@ def logSegfaulters( lastPaf ):
 		raise
 
 
-		
