@@ -17,6 +17,8 @@
 
 import wx
 import colorsys
+import subprocess,os
+import threading
 
 import wx.lib.statbmp 
 import fontcontrol
@@ -25,17 +27,44 @@ from pubsub import *
 from wxgui import ps
 
 ndc=(200,190,183) # No Draw Color: colour of background for the fonts I can't draw
+ndi=(227,226,219) # No Draw Inactive.
 black=(0,0,0)
 white=(255,255,255)
+
+class OverOutSignal(object):
+	'''
+	Signal an external function when a state has CHANGED from 
+	True to False or vice-vera
+	'''
+	def __init__( self, func_to_signal ):
+		self.announce = func_to_signal
+		self.state = False 
+		self.last_state = False
+	def __changed( self ):
+		if self.state != self.last_state: 
+			self.last_state = self.state
+			return True
+		return False
+	def set( self, truth ):
+		if self.state == truth:	return
+		self.state = truth
+		if self.__changed(): self.announce()
+
 class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 	"""
-	This class is a bitmap of a TTF font - it detects a click and 
-	also displays itself with other information below it.
+	This class is a bitmap of a TTF font - it detects events and 
+	displays itself.
+
+	Sept 2009
+	Added code to adjust top-left of displayed sample text.
+	
+	Oct 2009
+	Added a 'button' to open a character map viewer.
 	"""
 	
 	## This class-level dict is a kind of "style sheet" to use in fitmap drawing.
 	styles={
-			'FILE_NOT_FOUND':
+			'FILE_NOT_FOUND': #Needs purging
 				{
 					'backcol': (255,214,57),
 					'fcol'   : black,
@@ -44,10 +73,11 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 					},
 			'PIL_SEGFAULT_ERROR':
 				{
-					'backcol': (183,200,190),
+					'backcol': (152,147,157), #255,140,20),
 					'fcol'   : black,
 					'bcol'   : white,
-					'icon'	 : "SEGFAULT" ,
+					'icon'	 : "SEGFAULT",
+					'ndi'	 : (216,193,193)
 					},
 			'PIL_IO_ERROR':
 				{
@@ -55,6 +85,7 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 					'fcol'   : black,
 					'bcol'   : white,
 					'icon'	 : "NO_DRAW",
+					'ndi'	 : ndi
 					},
 			'PIL_UNICODE_ERROR':
 				{
@@ -62,6 +93,7 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 					'fcol'   : black,
 					'bcol'   : white,
 					'icon'	 : "NO_DRAW",
+					'ndi'	 : ndi
 					},
 			'PIL_CANNOT_RENDER':
 				{
@@ -69,6 +101,7 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 					'fcol'   : black,
 					'bcol'   : white,
 					'icon'	 : "NO_DRAW",
+					'ndi'	 : ndi
 					},
 			'ACTIVE':
 				{
@@ -96,73 +129,169 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 		self.name = fitem.name
 		
 		self.fitem = fitem
-		#self.parent = parent
 
 		Fitmap.styles['INFO_FONT_ITEM']['backcol']=parent.GetBackgroundColour()
 		self.FVP = parent.parent #The Font View Panel
 		self.TICKMAP = parent.parent.TICKMAP 
 		self.TICKSMALL = parent.parent.TICKSMALL
-		self.height =  0
+
 	
 		self.style = {} #Temporary space for style of fitem while drawing. It's a copy of one key from Fitem.styles
 		
-		## I control font's own height due to mad results.
-		## I based this on my preference. Some ttfs had these crazy heights
-		## and would shoot off the page. So, I nixed that.
-		self.maxHeight = int( fpsys.config.points * 1.55 )
-
 		# Some values for drawing
 		self.minHeight = 70
 		self.spacer = 35 # Gap below each font bitmap
 		self.gradientheight = 50
+		
+		self.width = parent.width # Get it from the scrollFontViewPanel.
 
+
+		## The charmap button
+		self.CHARMAP_BUTTON_OVER = self.FVP.BUTTON_CHARMAP_OVER
+		self.CHARMAP_BUTTON_OUT = self.FVP.BUTTON_CHARMAP
+		## Point to the handler for the signal re charmap button
+		self.cmb_overout = OverOutSignal( self.charmap_button_signal )
+
+
+		## Go draw the fitmap into a memory dc
 		self.bitmap = None
 		self.prepareBitmap()
-		
 		sz = (self.bitmap.GetWidth(), self.bitmap.GetHeight())
-	   
+
+		## Now I can calc the y value of the button.
+		self.cmb_rect=wx.Rect(0,sz[1]-40,19,32)
+		self.height =  0
+
 		## init my parent class 
 		self.gsb = wx.lib.statbmp.GenStaticBitmap.__init__(self, parent, -1, self.bitmap, pos, sz)
 
+		## Fitmap's over out signal
+		self.overout = OverOutSignal( self.overout_signal )
+
 		## Very cool event, gives us life!
 		self.Bind(wx.EVT_LEFT_UP,self.onClick) 
 		self.Bind(wx.EVT_MIDDLE_UP, self.onMiddleClick)	
-		
+		#self.Bind(wx.EVT_LEFT_DCLICK, self.onDClick)
+		self.Bind( wx.EVT_MOTION, self.onHover )
+
 		## Redraw event
 		self.Bind(wx.EVT_PAINT,  self.onPaint) 
 		
-		## Very cool,sets the icon for font items.
-		self.SetCursor( wx.StockCursor( wx.CURSOR_ARROW ) )
-		
-		## If this is *not* a FILE_NOT_FOUND then allow the cursor to change
-		## FILE_NOT_FOUND means we have a glyphpaf but no match on the drive.
-		## This means the Pog should be purged.
-		if self.fitem.badstyle != "FILE_NOT_FOUND":
-			if fpsys.state.action == "REMOVE":
-				self.SetCursor( wx.StockCursor( wx.CURSOR_PENCIL ) )
-			elif fpsys.state.action == "APPEND":
-				if not self.fitem.inactive:
-					self.SetCursor(wx.StockCursor(wx.CURSOR_HAND))
+		## Get cursors setup
+		self.CURSOR = wx.StockCursor( wx.CURSOR_ARROW )
+		if fpsys.state.action in ("REMOVE", "APPEND"):
+			self.CURSOR = wx.StockCursor( wx.CURSOR_HAND )
+		if self.fitem.badstyle == "FILE_NOT_FOUND":
+			self.CURSOR = wx.StockCursor( wx.CURSOR_ARROW )
+		if self.fitem.inactive:
+			self.CURSOR = wx.StockCursor( wx.CURSOR_ARROW )
 
-	@property # Cool.  I refer to blah.width and didn't want to alter them to blah.width(). This fixes that.
-	def width(self):
-		return self.FVP.getWidthOfMiddle()
 
-	def onPaint(self, event):
-		"""
-		Dump the bitmap to the screen.
-		"""
-		if self.bitmap:
-			## Create a buffered paint DC.  It will create the real
-			## wx.PaintDC and then blit the bitmap to it when dc is
-			## deleted.  Since we don't need to draw anything else
-			## here that's all there is to it.
-			dc = wx.BufferedPaintDC(self, self.bitmap, wx.BUFFER_VIRTUAL_AREA)
+	def openCharacterMap( self ):
+		fi=self.fitem
+		dirname = os.path.basename( fi.glyphpaf )
+		dest = os.path.join(fpsys.iPC.userFontPath(), dirname )
+
+		## I don't want to hold an fitem in the thread to come, so I will
+		## take the essential info out and make a tuple instead:
+		## (This is mere superstition and ignorance, I fear threads :) )
+
+		argstup=(fi.glyphpaf, dest, self.fitem.family[0],fpsys.config.points )
+
+		## Never done threading before. Not really sure if this is kosher...
+		thread = threading.Thread(target=self.run, args=argstup)
+		thread.setDaemon(True)
+		thread.start()
+
+	def run(self, *args):
+		src=args[0]
+		dest=args[1]
+		fam=args[2]
+		sz=args[3]
+
+		if fpsys.config.app_char_map == "gucharmap":
+			makelink=True
+			cmd = ['gucharmap', u'--font=%s, %s' % (fam, sz)]
+		elif fpsys.config.app_char_map == "kfontview":
+			makelink=False # kfontview only needs a url to a font file. It rules.
+			url = src
+			cmd = ['kfontview', u'%s' % url]
+		else:
+			return
+
+		if makelink:
+			## gucharmap requires the font to be installed already, so fake it:
+			fail=False
+			already_installed = False
+			try:
+				os.symlink( src, dest )
+			except OSError, detail:
+				if detail.errno != 17:
+					# Not 17 means the link failed, don't open the charmap
+					fail = True
+				else:
+					# Error 17: file exists.
+					# User may have installed it previously (or something).
+					already_installed = True
+			if fail: return
+
+		proc = subprocess.Popen( cmd, shell=False )
+		## gucharmap: Fonty actually holds still and waits here until gucharmap is closed.
+		## kfontview: Fonty just runs-through. kfontview is a different beast.
+		## Both still work and Fonty stays active. Multiple instances if the viewers can be opened!
+		proc.wait()
+
+		# Remove the fake installed font -- if it's a candidate:
+		if makelink and not already_installed:
+			try:
+				os.unlink( dest )
+			except:
+				# What to do? Start yelling? Nah...
+				pass
 
 	def onMiddleClick(self, event):
 		ps.pub( menu_settings, None )
 
+	def can_have_button( self ):
+		'''
+		Because I just can't guarantee that there is a family name
+		and because bad fonts that can't draw (but do not segfault)
+		are so rare that I can't bloody find any to test with (grrr)
+		I make the sweeping fiat that no badfonts will get a button.
+
+		Other fitems like info and FILE_NOT_FOUND don't get buttons.
+		'''
+		if not fpsys.config.app_char_map: return False
+		if isinstance( self.fitem, fontcontrol.InfoFontItem ): return False
+		if self.fitem.badstyle == "FILE_NOT_FOUND": return False
+		if not self.fitem.family: return False
+		return True
+
+	def onHover( self, e ):
+		if not self.can_have_button():
+			self.overout.set ( True )
+			return
+		if self.cmb_rect.Contains( e.GetPositionTuple() ):	
+			self.cmb_overout.set( True )
+			self.overout.set( False ) #Not 'on' fitmap
+		else:
+			self.cmb_overout.set ( False )
+			self.overout.set( True )
+	
+	def charmap_button_signal( self ):
+		if self.cmb_overout.state:
+			self.SetCursor(wx.StockCursor(wx.CURSOR_MAGNIFIER))
+		self.Refresh() # Force onPaint()
+
+	def overout_signal( self ):
+		if self.overout.state:
+			self.SetCursor( self.CURSOR )
+			
 	def onClick(self, event) :
+		if self.cmb_overout.state and self.can_have_button():
+			self.openCharacterMap()
+			return
+
 		if fpsys.state.cantick and not self.fitem.inactive:
 			self.fitem.ticked = not(self.fitem.ticked)
 			self.prepareBitmap() # This only redraws a single font item.
@@ -172,7 +301,71 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 			if self.fitem.ticked: fpsys.state.numticks += 1
 			if not self.fitem.ticked: fpsys.state.numticks -= 1
 			ps.pub(toggle_main_button)
-		event.Skip()	
+
+	def onPaint(self, event):
+		"""
+		Dump the bitmap to the screen.
+		"""
+		if self.bitmap:
+			## Create a buffered paint DC.  It will create the real
+			## wx.PaintDC and then blit the bitmap to it when dc is
+			## deleted.  
+			dc = wx.BufferedPaintDC(self, self.bitmap, wx.BUFFER_VIRTUAL_AREA)
+			
+			if not self.can_have_button(): return
+
+			# Draw the charmap button
+			x,y = self.cmb_rect[0],self.cmb_rect[1]
+			if self.cmb_overout.state:
+				dc.DrawBitmap( self.CHARMAP_BUTTON_OVER, x, y, True )
+			else:
+				dc.DrawBitmap( self.CHARMAP_BUTTON_OUT, x,y, True )
+
+	def CalculateTopLeftAdjustments(self, image, i, pilimage):
+		## Sept 2009
+		## Find the first pixel from the top-left of the image (if it's not stored)
+		## Using this pixel as the x,y I can draw fonts from where their actual data
+		## begins and not where the pilimage *thinks* it does (leaving big white spaces
+		## to the left of many fonts.)
+		
+		if fpsys.config.ignore_adjustments: return 0,0
+		wx.BeginBusyCursor()
+		if not self.fitem.top_left_adjust_completed:
+			W,H = pilimage.size
+			#if  not self.fitem.fx[i] and not self.fitem.fy[i]:
+			fx=fy=0
+			esc = False
+			# Scan ACROSS WIDTH and repeatedly DOWN looking for a pixel.
+			for tx in xrange(W):
+				for ty in xrange(H):
+					ap=image.GetAlpha(tx,ty)
+					#image.SetRGB(tx,ty,0,255,0)
+					#image.SetAlpha(tx,ty,255)
+					if ap != 0: #Found X coord, let's kill both loops
+						fx=tx
+						esc = True
+						break
+				if esc: break #uses fact that 0 is False
+			# Scan DOWN the HEIGHT and repeatedly ACROSS.
+			esc = False
+			for ty in xrange(H):
+				for tx in xrange(W):
+					ap=image.GetAlpha(tx,ty)
+					if ap != 0:
+						fy=ty # Found Y coord
+						esc = True
+						break
+				if esc: break
+			self.fitem.fx[i]=fx
+			self.fitem.fy[i]=fy
+			# If we are at the end of the number of faces (for ttc files this is > 0) then flag it true
+			if i+1 == self.fitem.numFaces: self.fitem.top_left_adjust_completed = True
+		else:
+			## Fetch the values from the cache list.
+			fx,fy = (self.fitem.fx[i], self.fitem.fy[i])
+		wx.EndBusyCursor()
+		return fx,fy
+
 
 	def prepareBitmap( self ):
 		"""
@@ -189,10 +382,7 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 		
 		## Get a list of pilimages, for each subface: Some fonts 
 		## have multiple faces, and their heights.
-		## If the height returned by PIL is larger than the maxHeight then
-		## I force pil to render to maxHeight.
 		## REMEMBER: This loop is all FOR THIS ONE FONT ITEM.
-		##
 		## It only supplies pilimages for fonts it could open and
 		## render. So this font may indeed have nothing in the pilList[]
 		## after this loop.
@@ -200,10 +390,10 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 		totheight = 0
 		maxwidth = [self.width] # to figure-out the biggest width
 
-		for pilimage,height,pilwidth in self.fitem.generatePilFont( self.maxHeight ):
-			pilList.append( [pilimage, height, pilwidth] )
-			totheight += height + self.spacer
-			maxwidth.append(pilwidth)
+		for pilimage in self.fitem.generatePilFont( ):
+			pilList.append( pilimage )
+			totheight += pilimage.size[1] + self.spacer
+			maxwidth.append(pilimage.size[0])
 		## Limit the minimum we allow.
 		if totheight < self.minHeight:
 			totheight = self.minHeight		
@@ -218,7 +408,8 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 		if self.fitem.badfont:
 			## We have a badstyle to help us differentiate these.
 			totheight = self.minHeight
-			memDc=self.drawInfoOrError(  self.width, totheight)#self.minHeight )
+			if self.fitem.inactive: totheight += 5 #Need more space
+			memDc=self.drawInfoOrError(  self.width, totheight )
 			
 		## It's *not* a badfont
 		else:
@@ -231,7 +422,9 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 			#Draw the gradient. The fonts will render in alpha over that.
 			self.bottomFadeEffect( memDc, totheight, maxwidth )
 			y = i = 0
-			for pilimage, glyphHeight, pilwidth in pilList:
+
+			for pilimage in pilList:
+				pilwidth, glyphHeight = pilimage.size
 				try:
 					## Get the data from PIL into wx.
 					## Now with alpha! Thanks to:
@@ -241,6 +434,9 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 					image = apply( wx.EmptyImage, pilimage.size )
 					image.SetData( pilimage.convert( "RGB").tostring() )
 					image.SetAlphaData(pilimage.convert("RGBA").tostring()[3::4])
+
+					fx,fy = self.CalculateTopLeftAdjustments( image, i, pilimage )
+
 					faceBitmap = image.ConvertToBitmap() 
 				except:
 					## Some new error that I have not caught before has happened.
@@ -248,14 +444,16 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 					## Draw error message into the memDc
 					memDc.SetTextForeground( fcol )
 					txt=_("This text cannot be drawn. Hey, it happens...")
-					memDc.SetFont( wx.Font( fpsys.config.points, family=wx.SWISS, style=wx.ITALIC, weight=wx.NORMAL))
+					memDc.SetFont( wx.Font( fpsys.config.points, fpsys.DFAM, style=wx.ITALIC, weight=wx.NORMAL))
 					memDc.DrawText( txt, 10, y+2)
 				else: #no error happened, we carry on.
 					## Place it into the main image, down a tad so it looks better.
-					facex = 5
+					facex = 10
 					if i > 0: facex *= 2 # Shift sub-faces over a little
 					## Draw the face into the memDc
-					memDc.DrawBitmap( faceBitmap, facex, y + 4, True )
+					psx = facex-fx# if (facex-fx) < 0 else psx = facex-fx
+					psy = y-fy
+					memDc.DrawBitmap( faceBitmap, psx, psy + 10, True )
 				
 				## Postion 
 				texty = y + glyphHeight + 8
@@ -267,24 +465,25 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 				txt = "%s - %s - [%s]" % (self.fitem.family[i], self.fitem.style[i], self.name)
 				memDc.SetTextForeground( fcol )
 				## Sep 2009: Trying to draw foreign chars via DrawText
-				memDc.SetFont( wx.Font( 8, family=wx.SWISS, style=wx.NORMAL, weight=wx.NORMAL,encoding=wx.FONTENCODING_DEFAULT))
-				memDc.DrawText( txt, 16, texty)
+				memDc.SetFont( wx.Font( 8,fpsys.DFAM , style=wx.NORMAL, weight=wx.NORMAL,encoding=wx.FONTENCODING_DEFAULT))
+				memDc.DrawText( txt, 28, texty)
 				
 				## Move TOP down to next BOTTOM (for next sub-face)
 				y = y + glyphHeight +  self.spacer
 					
 				## Goto next face, if any.
 				i += 1			
-		
+
 		## Record the calculated height
 		self.height = totheight
 
+
 		## Special message
 		if self.fitem.inactive:
-			mx,my=(27,self.height-20) if self.fitem.badfont else (27,self.height-26)
-			memDc.DrawBitmap( self.TICKSMALL, mx-20, my, True )
+			mx,my=(25,self.height-20) if self.fitem.badfont else (48,self.height-26)
+			memDc.DrawBitmap( self.TICKSMALL, mx-16, my-1, True )
 			memDc.SetTextForeground( black )
-			memDc.SetFont( wx.Font(11,family=wx.SWISS, style=wx.NORMAL, weight=wx.NORMAL))
+			memDc.SetFont( wx.Font(11,fpsys.DFAM, style=wx.NORMAL, weight=wx.NORMAL))
 			memDc.DrawText( self.fitem.activeInactiveMsg, mx, my )
 
 		## Draw the tick/cross if it's not a FILE_NOT_FOUND font (can't be found)
@@ -294,7 +493,7 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 				memDc.DrawBitmap(self.TICKMAP, 20, 5, True)
 			
 		## Now a dividing line
-		memDc.SetPen( wx.Pen( (200,200,200),1 ) )#black, 1 ) ) 
+		memDc.SetPen( wx.Pen( (180,180,180),1 ) )#black, 1 ) ) 
 		memDc.DrawLine( 0, self.height-1, maxwidth, self.height-1 )
 
 
@@ -305,14 +504,9 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 			self.style=Fitmap.styles[self.fitem.badstyle].copy() #damn! this was tricky!
 			if self.fitem.inactive:
 				self.style['fcol'] = Fitmap.styles['INACTIVE']['fcol']
-				# Dim the colour of the badfont to match look of other inactive fitems
-				bg=self.style['backcol']
-				hsv=self.rgb_to_hsv(bg)
-				sat=self.clamp(hsv[1]/2.5)
-				bright=self.clamp(hsv[2]*5.0)
-				nbg=self.hsv_to_rgb((hsv[0],sat,bright))
-				self.style['backcol'] = nbg
+				self.style['backcol'] = Fitmap.styles[self.fitem.badstyle]['ndi']
 			return
+
 		# Not bad font, just get vals from style sheet.
 		if self.fitem.inactive:
 			self.style = Fitmap.styles['INACTIVE']
@@ -352,7 +546,7 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 		sb = int(rgb[2]*255.0)
 		return ( sr,sg,sb )
 
-	def bottomFadeEffect( self, dc, height, width, step=1.12):
+	def bottomFadeEffect( self, dc, height, width, step=1.13):
 		"""
 		Baptiste's idea! New implementation : June 2009
 		 "Now a dividing gradient, you can say "wow" ;-)"
@@ -384,20 +578,26 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 		icon = self.style['icon']
 		if icon:
 			Icon = self.FVP.__dict__[icon]
-			ix,iy = (6,15) if isinfo else (2,3)
+			ix,iy = (6,10) if isinfo else (2,3)
 			memDc.DrawBitmap(Icon,ix,iy,True)
 
 		textTup = self.fitem.InfoOrErrorText()
 		
 		memDc.SetTextForeground( self.style['fcol'])
 		
-		memDc.SetFont( wx.Font(12, family=wx.SWISS, style=wx.NORMAL, weight=wx.BOLD))
-		tx,ty = (46,15) if isinfo else (33 ,13)
+		memDc.SetFont( wx.Font(12,fpsys.DFAM , style=wx.NORMAL, weight=wx.BOLD))
+		tx,ty = (46,15) if isinfo else (38 ,13)
 		memDc.DrawText( textTup[0], tx, ty)
 		
-		memDc.SetFont( wx.Font(7, family=wx.SWISS, style=wx.NORMAL, weight=wx.NORMAL))
-		tx,ty = (46,38) if isinfo else (8 ,38)
+		memDc.SetFont( wx.Font(7, fpsys.DFAM, style=wx.NORMAL, weight=wx.NORMAL))
+		tx,ty = (46,40) if isinfo else (5 ,40)
 		memDc.DrawText( textTup[1], tx, ty)
 
+
 		return memDc
 
+	#def DoGetBestSize(self):
+		#DOES NOT RUN
+		#print "			 FITMAP ?"
+
+
