@@ -17,6 +17,7 @@
 
 import wx
 import wx.lib.stattext
+import  wx.lib.buttons  as  buttons
 
 ## Setup wxPython to access translations : enables the stock buttons.
 langid = wx.LANGUAGE_DEFAULT # Picks this up from $LANG
@@ -94,6 +95,9 @@ class FontViewPanel(wx.Panel):
 		self.INFO_ITEM = wx.Bitmap(fpsys.mythingsdir + 'font_info_item.png', wx.BITMAP_TYPE_PNG)
 		self.TICKSMALL = wx.Bitmap(fpsys.mythingsdir + "ticksmall.png", type=wx.BITMAP_TYPE_PNG)
 
+		self.BUTTON_CHARMAP = wx.Bitmap(fpsys.mythingsdir + 'button_charmap.png', wx.BITMAP_TYPE_PNG)
+		self.BUTTON_CHARMAP_OVER = wx.Bitmap(fpsys.mythingsdir + 'button_charmap_over.png', wx.BITMAP_TYPE_PNG)
+
 		## Main Label on top
 		sizerMainLabel = wx.BoxSizer(wx.HORIZONTAL) 
 		self.textMainInfo = MyLabel(self)
@@ -107,7 +111,7 @@ class FontViewPanel(wx.Panel):
 		self.clearButton = wx.BitmapButton(self, -1, bmp, style = wx.NO_BORDER)
 		self.clearButton.SetToolTipString( _("Clear filter") )
 		self.clearButton.Bind( wx.EVT_BUTTON, self.OnClearClick )
-		
+
 		## The filter text box
 		self.textFilter = wx.StaticText(self, -1, _("Filter:"))
 		self.inputFilter = wx.ComboBox(self, 500, value="", choices=[],style=wx.CB_DROPDOWN )
@@ -124,13 +128,34 @@ class FontViewPanel(wx.Panel):
 
 		## put them into the sizer
 		sizerOtherControls.Add(self.textFilter, 0, wx.ALIGN_LEFT | wx.ALIGN_CENTER_VERTICAL)
+		
+		
+		## Quick search Bold Italic Regular buttons
+		self.BIR = { wx.NewId(): ["bold",False], wx.NewId(): ["italic",False], wx.NewId(): ["regular",False] }
+		for id, lst in self.BIR.iteritems():
+			bmp = wx.Bitmap(fpsys.mythingsdir + "button_%s.png" % lst[0], type=wx.BITMAP_TYPE_PNG)
+			bBIR = buttons.GenBitmapToggleButton(self, id, None, style=wx.BORDER_NONE ) #border looks crap, not native gtk.
+			self.BIR[id].append( bBIR )
+			bBIR.SetBitmapLabel(bmp)
+			bmp = wx.Bitmap(fpsys.mythingsdir + "button_%s_down.png" % lst[0], type=wx.BITMAP_TYPE_PNG)
+			## Kubuntu Jaunty KDE 4.ish : No amount of voodoo can get the background of the toggle buttons to
+			##  stop drawing in white. ThemedGenBitmapToggleButton does not work either.
+			##  c = wx.SystemSettings.GetColour(wx.SYS_COLOUR_BTNFACE) -> returns a nice gray. Using it does not help.
+			##  Setting backdrop to 'red' works fine.... Gray is the problem. Anyway, I am giving up. Perhaps
+			##  it will look better in pure Gnome.
+			bBIR.SetBitmapSelected(bmp)
+			bBIR.SetInitialSize()
+			sizerOtherControls.Add( bBIR, 0, wx.ALIGN_LEFT| wx.ALIGN_CENTER_VERTICAL )
+			bBIR.Bind( wx.EVT_BUTTON, self.onBIR )
+
 		sizerOtherControls.Add( self.clearButton, 0, wx.ALIGN_LEFT| wx.ALIGN_CENTER_VERTICAL ) # Clear button
+
 		sizerOtherControls.Add(self.inputFilter, 1, wx.ALIGN_LEFT | wx.EXPAND)
 		sizerOtherControls.Add(( 4,-1), 0, wx.EXPAND)
 		sizerOtherControls.Add(( 4,-1), 0, wx.EXPAND)
 		sizerOtherControls.Add(self.choicePage, 0 ,wx.EXPAND | wx.ALIGN_RIGHT)  #Added it to the sizer
 		
-		## The FONT panel:
+		## The SCROLLED FONT VIEW panel:
 		self.scrolledFontView = ScrolledFontView(self) 
 		
 		buttonsSizer = wx.BoxSizer(wx.HORIZONTAL) 
@@ -150,21 +175,22 @@ class FontViewPanel(wx.Panel):
 		buttonsSizer.Add(self.buttNext,0,wx.EXPAND) 
 
 		## Now the sizer to hold all the fontview controls
-		self.sizerFontView = wx.BoxSizer( wx.VERTICAL )
+		self.sizerScrolledFontView = wx.BoxSizer( wx.VERTICAL )
 		## The Main label
-		self.sizerFontView.Add(sizerMainLabel, 0, wx.EXPAND | wx.BOTTOM, border = 0 )
-		## The font view
-		self.sizerFontView.Add(self.scrolledFontView, 1, wx.EXPAND )
+		self.sizerScrolledFontView.Add(sizerMainLabel, 0, wx.EXPAND | wx.BOTTOM, border = 0 )
+
+		## The SIZER FOR THE SCROLLED FONT VIEW
+		self.sizerScrolledFontView.Add(self.scrolledFontView, 1, wx.EXPAND )
 
 		## The Search Assistant
-		#self.sizerFontView.Add( self.SA, 0, wx.EXPAND)
+		#self.sizerScrolledFontView.Add( self.SA, 0, wx.EXPAND)
 
 		## Choice and Filter
-		self.sizerFontView.Add(sizerOtherControls, 0, wx.EXPAND | wx.TOP | wx.BOTTOM, border = 3)
+		self.sizerScrolledFontView.Add(sizerOtherControls, 0, wx.EXPAND | wx.TOP | wx.BOTTOM, border = 3)
 		## The buttons   
-		self.sizerFontView.Add(buttonsSizer,0,wx.EXPAND)	
-		
-		self.SetSizer(self.sizerFontView)
+		self.sizerScrolledFontView.Add(buttonsSizer,0,wx.EXPAND)	
+
+		self.SetSizer(self.sizerScrolledFontView)
 	
 		e = wx.EVT_BUTTON #was wx.EVT_LEFT_UP
 		self.buttPrev.Bind(e,self.navClick) 
@@ -177,22 +203,45 @@ class FontViewPanel(wx.Panel):
 		ps.sub( toggle_main_button, self.ToggleMainButton ) ##DND: class FontViewPanel
 		ps.sub( update_font_view, self.MainFontViewUpdate ) ##DND: class FontViewPanel
 		ps.sub( reset_to_page_one, self.ResetToPageOne ) ##DND: class FontViewPanel 
-
-	def getWidthOfMiddle( self ):
-		if self.firstrun:
-			return fpsys.config.size[0]# Use the last known width of the entire window as an initial size estimate.
-		else:
-			return self.sizerFontView.GetSize()[0] # After this flag is tripped, the app is aware of sizes and we can get a real number.
+	
+	#def DoGetBestSize(self):
+		# DOES NOT RUN FOR A wx.Panel
 
 	def OnClearClick( self, event ):
 		self.inputFilter.SetValue("") #was .Clear(), but that does not work for a combo box.
 		self.filter = ""
+		
+		# Clear the BIR toggle buttons
+		self.setBIRFalse()
+
 		## Now command a change of the view.
 		## First, return user to page 1:
 		self.pageindex = 1
 		self.filterAndPageThenCallCreateFitmaps()
 		self.buttMain.SetFocus()  #a GTK bug demands this move. Restore the ESC key func.
 
+	def setBIRFalse( self ):
+		for id in self.BIR.keys():
+			self.BIR[id][1] = False
+			self.BIR[id][2].SetToggle( False )
+
+	def onBIR( self, e ):
+		id=e.GetId()
+		self.BIR[id][1]=e.GetIsDown()
+		if self.BIR[id][0] == "regular":
+			# can't have regular with bold/italic
+			self.setBIRFalse() # switch all off
+			self.BIR[id][1]=True #switch regular back on
+			ss = "regular|normal"
+		else:
+			ss=""
+			for id, lst in self.BIR.iteritems():
+				if lst[1]: ss += "%s%s" % (lst[0]," ") # Builds AND regex (space is and)
+			ss = ss[:-1]
+	
+		self.inputFilter.SetValue( ss )
+		self.startSearch( ss )
+		
 	# Capture events when the user types something into the control then
 	# hits ENTER.
 	def EvtTextEnter(self, evt):
@@ -206,13 +255,12 @@ class FontViewPanel(wx.Panel):
 		
 		self.buttMain.SetFocus()
 		evt.Skip()
+
 	# When the user selects something in the combo pull-down area, we go here.
 	def EvtComboBox(self, evt):
 		cb = evt.GetEventObject()
 		termsstring = evt.GetString()
-
 		self.startSearch(termsstring)
-		
 		self.buttMain.SetFocus()
 
 	def startSearch(self, terms):
@@ -288,7 +336,7 @@ class FontViewPanel(wx.Panel):
 		self.scrolledFontView.CreateFitmaps( sublist ) # Tell my child to draw the fonts
 		self.EnableDisablePrevNext()
 
-		self.firstrun = False # After all the fitmaps are drawn, the sizer knows how wide it is, so we trip this flag (see getWidthOfMiddle)
+		#self.firstrun = False # After all the fitmaps are drawn, the sizer knows how wide it is, so we trip this flag (see getWidthOfMiddle)
 
 	def onMainClick(self, evt) :
 		"""
@@ -558,48 +606,45 @@ class MyLabel( wx.lib.stattext.GenStaticText ):
 	def __init__(self, parent):
 		self.FVP = parent
 		self.lab = u" " 
-		self.infoFont = wx.Font(12, wx.FONTFAMILY_DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD)
-		self.light = wx.SystemSettings.GetColour( wx.SYS_COLOUR_3DHIGHLIGHT )
+		self.infoFont = wx.Font(11, fpsys.DFAM, wx.NORMAL, wx.FONTWEIGHT_BOLD)
+		self.light = (255,255,255)#wx.SystemSettings.GetColour( wx.SYS_COLOUR_3DHIGHLIGHT )
 		self.dark = wx.SystemSettings.GetColour(wx.SYS_COLOUR_3DSHADOW)
 		self.back = parent.GetBackgroundColour()
 		self.h=100
+		self.width = 10
 
 		self.VIEWICON = wx.Bitmap(fpsys.mythingsdir + "view16x16.png", type=wx.BITMAP_TYPE_PNG)
 
 		# call parent init after vital settings are done.
 		wx.lib.stattext.GenStaticText.__init__(self, parent, -1," ")
 		self.Bind(wx.EVT_PAINT, self.OnPaint)
+		self.Bind(wx.EVT_SIZE, self.OnSize)
+
+	def OnSize(self,e):
+		self.width=self.FVP.GetSize()[0]
+		self.Refresh()
+
 	def SetLabel( self, lab ):
 		self.lab=lab
 		self.Refresh()
-	def DoGetBestSize(self):
-		dc = wx.ClientDC(self)
-		dc.SetFont(self.infoFont)
-		bestw,besth = dc.GetTextExtent(self.lab) or (100,100)
-		besth += 8
-		best = wx.Size(bestw,besth)
-		self.CacheBestSize(best)
-		self.h=besth
-		return best
-	def OnPaint(self, event):
-		pdc = wx.PaintDC(self)
-		try:
-			dc = wx.GCDC(pdc)
-		except:
-			dc = pdc
-		w=(dc.GetFullTextExtent(self.lab,self.infoFont)[0] or 100) + 40 
 
+	def DoGetBestSize(self):
+		bestw,self.h = (100,26)
+		best = wx.Size(bestw,self.h) 
+		self.CacheBestSize(best)
+		return best
+
+	def OnPaint(self, event):
+		dc = wx.PaintDC(self)
+		w = self.width
+		w -= wx.SystemSettings.GetMetric(wx.SYS_VSCROLL_X) # minus width of the scrollbar
 		#Now draw the thing:
 		rect = wx.Rect(0,0, w, self.h + 10)
 		
 		dc.SetPen(wx.Pen(self.dark,width=1))
-		dc.SetBrush(wx.Brush(self.back))
+		dc.SetBrush( wx.TRANSPARENT_BRUSH ) 
 
-		#rect.SetPosition( (0,0) )
 		dc.DrawRoundedRectangleRect(rect, 5)
-		
-		#The gradient under the text
-		dc.GradientFillLinear( wx.Rect(2, self.h-15, w-3, self.h-2), self.light, self.back, nDirection=wx.NORTH )
 
 		# The text
 		dc.SetFont(self.infoFont) 
@@ -607,3 +652,37 @@ class MyLabel( wx.lib.stattext.GenStaticText ):
 
 		dc.DrawBitmap( self.VIEWICON, 6,5, True)
 
+
+
+	# Old code -- keep for ref....
+
+	def OLD_DoGetBestSize(self):
+		dc = wx.ClientDC(self)
+		dc.SetFont(self.infoFont)
+		# How big is the text?
+		bestw,besth = dc.GetTextExtent(self.lab) or (100,100)
+		besth += 8
+		best = wx.Size(bestw,besth) 
+		self.CacheBestSize(best)
+		self.h=besth
+		return best
+
+
+	def OnPaintFakeTab(self, event):
+		'''Old fake tab look. Keep for future ref.'''
+		pdc = wx.PaintDC(self)
+		try:
+			dc = wx.GCDC(pdc)
+		except:
+			dc = pdc
+		w=(dc.GetFullTextExtent(self.lab,self.infoFont)[0] or 100) + 40 
+		rect = wx.Rect(0,0, w, self.h + 10)
+		dc.SetPen(wx.Pen(self.dark,width=1))
+		dc.SetBrush(wx.Brush(self.back))
+		dc.DrawRoundedRectangleRect(rect, 5)
+		#The gradient under the text
+		dc.GradientFillLinear( wx.Rect(2, self.h-15, w-3, self.h-2), self.light, self.back, nDirection=wx.NORTH )
+		# The text
+		dc.SetFont(self.infoFont) 
+		dc.DrawText(self.lab, 27,5)
+		dc.DrawBitmap( self.VIEWICON, 6,5, True)
