@@ -152,21 +152,15 @@ class MainFrame(wx.Frame):
 		self.panelNotebook = wx.Panel(self.splitter) 
 		
 		## Notebook label and icon
-		self.viewIcon = wx.StaticBitmap\
-		(self.panelNotebook, -1, wx.Bitmap\
-		(fpsys.mythingsdir + 'icon_source_16x16.png', wx.BITMAP_TYPE_PNG))		
-		self.viewLabel = wx.StaticText\
-		(self.panelNotebook, -1, _("Source, Folder or Pog"), style = wx.ALIGN_LEFT)
-		self.viewLabel.SetFont\
-		(wx.Font(10, wx.FONTFAMILY_DEFAULT, wx.NORMAL, wx.FONTWEIGHT_BOLD))
+		self.viewIcon = wx.StaticBitmap( self.panelNotebook, -1, wx.Bitmap( fpsys.mythingsdir + 'icon_source_16x16.png', wx.BITMAP_TYPE_PNG ))		
+		self.viewLabel = wx.StaticText( self.panelNotebook, -1, _("Source, Folder or Pog"), style = wx.ALIGN_LEFT )
+		self.viewLabel.SetFont( wx.Font(10, fpsys.DFAM, wx.NORMAL, wx.FONTWEIGHT_BOLD) )
 		
 		## A horiz sizer to hold the icon and text
 		self.sizer_iconandtext = wx.BoxSizer(wx.HORIZONTAL)
-		self.sizer_iconandtext.Add((4,1),0)
-		self.sizer_iconandtext.Add\
-		(self.viewIcon, 0, wx.TOP | wx.BOTTOM, border = 4)
-		self.sizer_iconandtext.Add\
-		(self.viewLabel, 1, wx.EXPAND | wx.TOP | wx.BOTTOM | wx.LEFT, border = 4)
+		self.sizer_iconandtext.Add( (4, 1), 0 )
+		self.sizer_iconandtext.Add( self.viewIcon, 0, wx.TOP | wx.BOTTOM, border = 4 )
+		self.sizer_iconandtext.Add( self.viewLabel, 1, wx.EXPAND | wx.TOP | wx.BOTTOM | wx.LEFT, border = 4 )
 		
 		## Now the actual notebook
 		self.nb = NoteBook(self.panelNotebook)
@@ -185,11 +179,12 @@ class MainFrame(wx.Frame):
 		self.splitter2 = Splitter(self.splitter) # gets the second slot of splitter
 		
 		## Font View Panel Control:
-		self.panelFontView = FontViewPanel(self.splitter2) # first slot in splitter2
+		self.fontViewPanel = FontViewPanel(self.splitter2) # first slot in splitter2
 		
 		self.sizerFontView  = wx.BoxSizer(wx.VERTICAL) 
-		self.sizerFontView.Add(self.panelFontView, 1, wx.EXPAND)
-		self.panelFontView.Layout()
+		self.sizerFontView.Add(self.fontViewPanel, 1, wx.EXPAND)
+		self.sizerFontView.SetDimension( 0, 0, 1024, 0)
+		#self.fontViewPanel.Layout()
 	   
 		## THE FAR RIGHT HAND SIDE
 		## The TargetPogChooser
@@ -200,12 +195,10 @@ class MainFrame(wx.Frame):
 		self.panelTargetPogChooser.Layout()
 		
 		self.splitter.SetMinimumPaneSize(64) 
-		self.splitter.SplitVertically\
-		(self.panelNotebook, self.splitter2, fpsys.config.leftSash )
+		self.splitter.SplitVertically( self.panelNotebook, self.splitter2, fpsys.config.leftSash )
+		
 		self.splitter2.SetMinimumPaneSize(128)
-		# Negative here means pixels from the right edge.
-		self.splitter2.SplitVertically\
-		(self.panelFontView, self.panelTargetPogChooser, -fpsys.config.rightSash )
+		self.splitter2.SplitVertically( self.fontViewPanel, self.panelTargetPogChooser) #Don't suggest a size here.
 
 		self.SetCursor(wx.StockCursor(wx.CURSOR_ARROW))
 		
@@ -220,14 +213,16 @@ class MainFrame(wx.Frame):
 
 		ps.sub( toggle_purge_menu_item, self.TogglePurgeMenuItem ) ##DND: class MainFrame
 
-		## When splitter is changed (after the drag), we want to redraw
-		## the fonts to the new width.
-		self.splitter.Bind(wx.EVT_SPLITTER_SASH_POS_CHANGED, self.onSize)
-		
-		self.Layout()
-
 		## call the big one - the big chief, the big cheese:
+		## This eventually draws all the Fitmaps - giving the middle have a width.
 		ps.pub( update_font_view ) #DND: It's in gui_Middle.py under class FontViewPanel
+	
+		self.splitter.Bind(wx.EVT_SPLITTER_SASH_POS_CHANGED, self.onSize) #Give splitter an event (not splitter2) weird.
+
+		# Force splitter2 to the correct position. 
+		self.splitter2.SetSashPosition( -fpsys.config.rightSash, redraw=False )
+
+		self.Layout()
 
 		## A nasty looking line to call the SortOutTheDamnImages function
 		## This is to draw the right icons depending on the params from cli.
@@ -295,11 +290,17 @@ class MainFrame(wx.Frame):
 			num = int(dlg.inputPageLen.GetValue())
 			points = int(dlg.inputPointSize.GetValue())
 			txt = dlg.inputSampleString.GetValue()
+			ignoreAdjust = dlg.chkAdjust.GetValue() #Sept 2009
 			if (num, txt, points) != (lastnuminpage, lastpoints, lasttext):
 				fpsys.config.numinpage = int(num)
 				fpsys.config.points = int(points)
 				if len(txt) > 0: fpsys.config.text =  txt
+			
+			fpsys.config.ignore_adjustments = ignoreAdjust #Sept 2009
+			fpsys.config.app_char_map = dlg.CHOSEN_CHARACTER_MAP # Oct 2009
 			## Now to refresh things:
+			## Sept 2009 : size change means we need new values for fitmaps
+			ps.pub( reset_top_left_adjustments ) ##DND : In ScrolledFontView
 			ps.pub( update_font_view )
 		dlg.Destroy()
 
@@ -379,7 +380,7 @@ class MainFrame(wx.Frame):
 ## Use ctrl+alt+i to open it.
 #import wx.lib.mixins.inspection
 ## Start the main frame and then show it.
-class App(wx.App):#, wx.lib.mixins.inspection.InspectionMixin) :
+class App(wx.App ):#, wx.lib.mixins.inspection.InspectionMixin) :
 	def OnInit(self):
 		#self.Init()  # initialize the inspection tool
 		
@@ -391,15 +392,17 @@ class App(wx.App):#, wx.lib.mixins.inspection.InspectionMixin) :
 		bmp=wx.Image(fpsys.mythingsdir + "splash.png",wx.BITMAP_TYPE_PNG).ConvertToBitmap()
 		ss=wx.SplashScreen( bmp, wx.SPLASH_CENTRE_ON_SCREEN, 1, None, -1)
 
+		## Oct 2009
+		##  this is the only place I can get the system font family
+		fpsys.DFAM = wx.SystemSettings.GetFont(wx.SYS_DEFAULT_GUI_FONT).GetFamily()
+
 		frame = MainFrame(None, _("Fonty Python: bring out your fonts!"))
-		
 		self.SetTopWindow(frame) 
 		
 		frame.Show(True) 
 		ss.Close()
 
 		return True
-		
 ## app
 app = App(0) 
 		
